@@ -282,7 +282,7 @@ class SecureFlaskApp(Flask):
                 response = render_template(self.__custom_403) if self.__custom_403 \
                                else jsonify(dict(message="Unauthorized")), 403
                 if "cas-object" not in session:
-                    after_login = f"{request.path}{_parse_query_string(quoted=True)}"
+                    after_login = f"{request.path}{_parse_query_string(quoted=False)}"
                     session["cas-after-login"] = after_login
                     response = _login(self.__cas_server_url, self.app_url)
                 else:
